<?php
/*
 * Plugin Name: FontSizeSelect
 * Version: 1.9.1
 * Plugin URI: https://nhws.localinfo.jp/
 * Description: Visitors can select the default FontSize.
 * Author: NORTH HILL WORK STUDIO
 * Author URI: https://nhws.localinfo.jp/
 * Changelog: 	Template-file ready for fp-1.3/ smarty 4
 * 				added german translation
 * 				Text decoration of buttons removed when mouse over
 * Change-Date:	07.11.2022, by Fraenkiman
 */ 


register_widget('fontsizeselect', 'FontSizeSelect', 'plugin_fontsizeselect_widget');
add_action('wp_head', 'plugin_fontsizeselect_head');
add_action('wp_footer', 'plugin_fontsizeselect_footer');


function plugin_fontsizeselect_widget() {
	
	$fontsizeselectconf = plugin_getoptions('fontsizeselect');	// Read out the settings
	$lang = lang_load('plugin:fontsizeselect');	// Multilingual support
	
	$fontsizeselectconf ['sizes'] = isset($fontsizeselectconf ['sizes']) ? $fontsizeselectconf ['sizes'] : "1";
	$fontsizeselectconf ['sizem'] = isset($fontsizeselectconf ['sizem']) ? $fontsizeselectconf ['sizem'] : "1.1";
	$fontsizeselectconf ['sizel'] = isset($fontsizeselectconf ['sizel']) ? $fontsizeselectconf ['sizel'] : "1.2";
	
	if ($fontsizeselectconf ['display'] == '1') $title = $lang ['plugin'] ['fontsizeselect'] ['title'];
	
	$content = "<div class=\"fontsizeselect\">
	<span>{$title}</span>
	<a href=\"javascript:void(0);\" style=\"text-decoration: none;\" onclick=\"tglBtn('{$fontsizeselectconf['sizes']}em');bgChg(this);\">&nbsp;{$lang ['plugin'] ['fontsizeselect'] ['small']}&nbsp;</a> | <a href=\"javascript:void(0);\" style=\"text-decoration: none;\" onclick=\"tglBtn('{$fontsizeselectconf ['sizem']}em');bgChg(this);\">&nbsp;{$lang ['plugin'] ['fontsizeselect'] ['middle']}&nbsp;</a> | <a href=\"javascript:void(0);\" style=\"text-decoration: none;\" onclick=\"tglBtn('{$fontsizeselectconf ['sizel']}em');bgChg(this);\">&nbsp;{$lang ['plugin'] ['fontsizeselect'] ['large']}&nbsp;</a>
	</div>";
	
	return array(
		'subject' => $lang ['plugin'] ['fontsizeselect'] ['title'],
		'content' => $content
	);
}


function plugin_fontsizeselect_head() {
	
	$fontsizeselectconf = plugin_getoptions('fontsizeselect');	// Read out the settings
	$pdir = plugin_geturl('fontsizeselect');
	$fontsizeselectconf ['type'] = isset($fontsizeselectconf ['type']) ? $fontsizeselectconf ['type'] : "1";
	
	echo '
	<!-- start of fontsizeselect -->
	<link rel="stylesheet" type="text/css" href="' . $pdir . 'res/fontsizeselect' . $fontsizeselectconf ['type'] . '.css">
	<script src="' . $pdir . 'res/fontsizeselect.js"></script>
	<script>var nhwsFontSizeStorage = localStorage;</script>
	<!-- end of fontsizeselect -->
	';
}


function plugin_fontsizeselect_footer() {
	
	$fontsizeselectconf = plugin_getoptions('fontsizeselect');	// Read out the settings
//	$pdir = plugin_geturl('fontsizeselect');
	
	echo '
	<!-- start of fontsizeselect -->
		<script>
			/**
			 * Initializes the fontsizeselect plugin.
			 */
			var cols = document.querySelectorAll(\'.fontsizeselect a\');
			var setSize = nhwsFontSizeStorage.getItem(\'fpFontSizeSelect\');
				if (!setSize) setSize = \'' . $fontsizeselectconf ['sizes'] . 'em\';
					tglBtn(setSize);
				if (setSize == \'' . $fontsizeselectconf ['sizes'] . 'em\') cols [0].classList.add(\'selected\');
				if (setSize == \'' . $fontsizeselectconf ['sizem'] . 'em\') cols [1].classList.add(\'selected\');
				if (setSize == \'' . $fontsizeselectconf ['sizel'] . 'em\') cols [2].classList.add(\'selected\');
		</script>
	<!-- end of fontsizeselect -->
	';
}


if (class_exists('AdminPanelAction')){
	/*
	 * Provides an admin panel entry for FontSizeSelect setup.
	 */
	class admin_plugin_fontsizeselect extends AdminPanelAction { 
		var $langres = 'plugin:fontsizeselect';
		
		/*
		 * Initializes this panel.
		 */
		function setup() {
			$this->smarty->assign('admin_resource', "plugin:fontsizeselect/admin.plugin.fontsizeselect");
		}
		
		/*
		 * Setups the default panel.
		 */
		function main() {
			$fontsizeselectconf = plugin_getoptions('fontsizeselect');	// Read out the settings
			
			$fontsizeselectconf ['sizes'] = isset($fontsizeselectconf ['sizes']) ? $fontsizeselectconf ['sizes'] : "1";
			$fontsizeselectconf ['sizem'] = isset($fontsizeselectconf ['sizem']) ? $fontsizeselectconf ['sizem'] : "1.1";
			$fontsizeselectconf ['sizel'] = isset($fontsizeselectconf ['sizel']) ? $fontsizeselectconf ['sizel'] : "1.2";
			$fontsizeselectconf ['type'] = isset($fontsizeselectconf ['type']) ? $fontsizeselectconf ['type'] : "1";
			
			$this->smarty->assign('fontsizeselectconf', $fontsizeselectconf);
		}
		
		/*
		 * Will be executed when the FontSizeSelect configuscorethresholdn is send.
		 *		
		 * @return int
		 */
		function onsubmit($data = null) {
			global $fp_config;
			if ($_POST ['sizel'] && $_POST ['sizem'] && $_POST ['sizes'] &&  $_POST ['type']){
				if (!(2 >= $_POST ['sizel'] && $_POST ['sizel'] > $_POST ['sizem'] && $_POST ['sizem'] > $_POST ['sizes'] && $_POST ['sizes'] >= 0.5)){
					$_POST ['sizes'] = 1;
					$_POST ['sizem'] = 1.1;
					$_POST ['sizel'] = 1.2;
				}
				plugin_addoption('fontsizeselect', 'sizes', $_POST ['sizes']);
				plugin_addoption('fontsizeselect', 'sizem', $_POST ['sizem']);
				plugin_addoption('fontsizeselect', 'sizel', $_POST ['sizel']);
				plugin_addoption('fontsizeselect', 'type', $_POST ['type']);
				plugin_addoption('fontsizeselect', 'display', $_POST ['display']);
				plugin_saveoptions('fontsizeselect');
				
				$this->smarty->assign('success', 1);
			} else {
				$this->smarty->assign('success', -1);
			}
			return 2;
		}		
	}
	admin_addpanelaction('plugin', 'fontsizeselect', true);
}


?>
